Vital Horizon AI CLI authentication support package

* [Product documentation](https://docs.tryvital.io/api-reference/horizon-ai/)

## License

AGPL 3.0. Refer to [the LICENSE](/LICENSE.txt) for more information.
